@@ -716,8 +716,9 @@ class Env(BaseEnv):
         return env
 
     @classmethod
-    def get_env_path(cls) -> Path:
-        return cls.Meta.root / f"env_{cls.Meta.stage}.py"
+    def get_env_path(cls, stage: Optional[str] = None) -> Path:
+        stage = stage or cls.Meta.stage
+        return cls.Meta.root / f"env_{stage}.py"
 
     def _collect_magic_functions(self) -> None:
         """
